unit brushstylecombo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  Tbrushstylecombo = class(TCustomComboBox)
  private
    function GetSelection: TBrushStyle;
    procedure SetSelection(Value: TBrushStyle);
  protected
    procedure SetStyle(Value: TComboBoxStyle); override;
    procedure DrawItem(Index: Integer; Rect: TRect;
      State: TOwnerDrawState); override;
    procedure CreateWnd; override;
  public
    constructor Create(AOwner: TComponent); override;
    procedure SetStyleList; virtual;
    property Selection: TBrushStyle read GetSelection write SetSelection;
  published
    property Color;
    property Ctl3D;
    property DragMode;
    property DragCursor;
    property DropDownCount;
    property Enabled;
    property Font;
    property ItemHeight;
    property Items;
    property MaxLength;
    property ParentColor;
    property ParentCtl3D;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property Sorted;
    property TabOrder;
    property TabStop;
    property Text;
    property Visible;
    property OnChange;
    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnDrawItem;
    property OnDropDown;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;
    property OnMeasureItem;
    property OnStartDrag;
  end;

procedure Register;

implementation
uses extctrls;

const
  BrushStyleArray: array[0..7] of string =
  ('Solid', 'Clear', 'Horizontal', 'Vertical', 'Diagonal Right', 'Diagonal Left', 'Cross', 'DiagCross');

procedure Register;
begin
  RegisterComponents('Smart', [Tbrushstylecombo]);
end;

function Tbrushstylecombo.GetSelection:TBrushStyle;
begin
  result:=TBrushStyle(ItemIndex);
end;

procedure Tbrushstylecombo.SetSelection(Value: TBrushStyle);
var
  i: integer;
begin
  for i:=0 to 7 do
    if TBrushStyle(i) = Value then
    begin
      ItemIndex :=i;
      exit;
    end;  
end;

procedure Tbrushstylecombo.SetStyle(Value: TComboBoxStyle);
begin
  inherited SetStyle(csOwnerDrawFixed);
end;

procedure Tbrushstylecombo.DrawItem(Index: Integer; Rect: TRect; State: TOwnerDrawState);
var
  r             :TRect;
  ItemColor     :TColor;
  s             :TShape;

begin
  r.top := Rect.top+1;
  r.bottom := Rect.bottom-1;
  r.left := Rect.left + 3;
//  r.right := r.left + (r.Right-r.Left);
  r.right := r.left + 40;

  with Canvas do
  begin
    FillRect(Rect);
    pen.color:=clBlack;
    canvas.brush.color:=clBlack;
    canvas.brush.style:=TBrushStyle(Index);
    rectangle(r.left,r.top,r.Right,r.Bottom);
    rectangle(r.left,r.top,r.left + 40,r.Bottom);

    canvas.brush.style:=TBrushStyle(1);
    textout(r.left + 45,r.top,BrushStyleArray[index]);
    FrameRect(r);
  end;
  r := Rect;
//  r.left := r.left + 40;
  r.left := r.left + (r.Right-r.Left);

    canvas.brush.style:=bsSolid;
    canvas.brush.color:=clSilver;
  inherited DrawItem(Index, r, State);
end;

procedure Tbrushstylecombo.CreateWnd;
begin
  inherited CreateWnd;
  SetStyleList;
end;

constructor Tbrushstylecombo.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Style := csOwnerDrawFixed;
end;

procedure Tbrushstylecombo.SetStyleList;
var
  c: integer;
  s: String;
begin
  if csDesigning in ComponentState then
    with items do
    begin
      clear;
      for c := 0 to High(BrushStyleArray) do
        Add(BrushStyleArray[c]);
    end;
end;


end.
